//
//  BXVersionController.h
//  Boinx Services Framework
//
//  Created by Michael Ehrmann on Thu Mar 18 2004.
//  Copyright (c) 2004 GeBE Computer & Peripherie GmbH. All rights reserved.
//



/*!
@header BXVersionController
@copyright Copyright 2004 GeBE Computer & Peripherie GmbH. All rights reserved.
@updated 2005-07-03
*/

extern NSString *const BXVersionControllerAppVersionDidChangeNotification;
extern NSString *const BXVersionControllerQuickTimeVersionDidChangeNotification;
extern NSString *const BXVersionControllerSystemBuildDidChangeNotification;
extern NSString *const BXVersionControllerSystemVersionDidChangeNotification;
	
#import <Foundation/Foundation.h>

@class BXVersionCheckWindowController, BXReadMeWindowController;


/*!
@class
@abstract    BXVersionController kann über das Web überprüfen, ob eine neue Version der laufenden Applikation vorhanden ist.
@discussion  
@updated 2005-07-03
*/

@interface BXVersionController : NSObject {
BXVersionCheckWindowController *versionCheckWindowController;
BXReadMeWindowController *readMeController;

NSString *versionDictUrl;
}




#pragma mark Preference default values


/*!
@method
 @abstract   Registriert die Standartwerte der verschiedenen Einstellungen für das Versionchecking-Framework in den Userdefaults.
 @discussion 
 */
+ (void)registerPreferenceDefaults;




#pragma mark Application state methods


/*!
@method     
 @abstract   Überprüft ob diese Version der Applikation das Erste mal gestartet wurde.
 @discussion Diese Klassenmethode vergleicht die <b>CFBundleVersion</b> (Revision Number), die im 
 Info.plist definiert sein muss mit der Versionsnummer, die beim letzten Beenden in die 
 UserDefaults geschrieben wurde. Falls die zwei Zahlen ungleich sind liefert die Methode 
 den Wert <b>YES</b> zurück, ansonsten <b>NO</b>.
 */
+ (BOOL)firstStartOfAppVersion;


/*!
@method     
 @abstract   Überprüft ob seit dem letzten start der Applikation eine neue QuckTime Version installiert wurde.
 @discussion Beim Beenden der Applikatio wird die aktuell installierte QuickTime-Version in die UserDefaults der 
 Applikation geschrieben. Diese Versionsnummer wird in dieser Methode mit der aktuellen QickTime Version verglichen.
 Bei ungleichheit der beiden Versionsnummern gibt die Methode <b>YES</b> zurück, ansonsten <b>NO</b>.
 */
+ (BOOL)firstStartWithQuickTimeVersion;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
+ (BOOL)firstStartWithSystemBuild;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
+ (BOOL)firstStartWithSystemVersion;




#pragma mark Utils


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
+ (BOOL)isWebKitAvailable;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
+ (NSString*)defaultVersionDictURL;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
+ (void)openURLForKey:(NSString*)key fromVersionDictWithURL:(NSString*)versionDictURL;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
+ (BOOL)serverIsReachable:(NSString *)server;




#pragma mark Konstruktor


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (id)initWithUrl:(NSString*)urlString; 




#pragma mark Handling notifications


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)registerForNotifications;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)unregisterForNotifications;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)applicationWillFinishLaunching:(NSNotification*)aNotification;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)applicationDidFinishLaunching:(NSNotification*)aNotification;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)applicationWillTerminate:(NSNotification*)aNotification;




#pragma mark Interactiong with Nib-File



/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)awakeFromNib;




#pragma mark IBActions



/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (IBAction)checkForNewVersion:(id)sender;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (IBAction)showReadMe:(id)sender;




#pragma mark Instance methods



/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)automaticCheckForNewVersion;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (BOOL)isVersionUpToDate:(NSString*)betaString withDictionary:(NSDictionary*)productVersionDict  currentReleaseNumber:(id)currentReleaseNumber;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */

- (BOOL)isTimeForVersionCheck;


/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)openURLbyKey:(NSString*)theURLKey;




#pragma mark Accessors



/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (NSString*)versionDictUrl;



/*!
@method     
 @abstract   (brief description)
 @discussion (comprehensive description)
 */
- (void)setVersionDictUrl:(NSString*)newVersionDictUrl;

@end
